--***************************************************************
--
-- wheelWeightConfig
-- 
-- version 1.00 by mogli (biedens)
-- 2017/11/19 - version 1.0 (FS17)
--
--***************************************************************

wheelWeightConfig = {}

--********************************
-- registerConfigurationType
--********************************
ConfigurationUtil.registerConfigurationType("wheelWeight", g_i18n:getText("wheelWeightConfig"),  nil, nil, nil, ConfigurationUtil.SELECTOR_MULTIOPTION)

--********************************
-- prerequisitesPresent
--********************************
function wheelWeightConfig.prerequisitesPresent(specializations) 
	return true
end 

--********************************
-- load
--********************************
function wheelWeightConfig:load(savegame)
end

--********************************
-- postLoad
--********************************
function wheelWeightConfig:postLoad(savegame)

  -- wheel weight setup
  local wheelWeightId  = Utils.getNoNil(self.configurations["wheelWeight"], 1);
  local configKey = string.format("vehicle.wheelWeightConfigurations.wheelWeightConfiguration(%d)", wheelWeightId-1);
  local key = configKey..".wheelWeights";
	
	--print('wheelWeightConfig:postLoad : key="'..tostring(key)..'"')
	
  if self.configurations["wheelWeight"] ~= nil and not hasXMLProperty(self.xmlFile, configKey.."#name") then
    print("Warning: Invalid wheelWeightId '"..tostring(self.configurations["wheelWeight"]).."'. Using default wheel weight settings instead!");
  end;

  ObjectChangeUtil.updateObjectChanges(self.xmlFile, "vehicle.wheelWeightConfigurations.wheelWeightConfiguration", wheelWeightId, self.components, self);

  self.wheelWeights = {};
  local i = 0;
  while true do
    local wheelWeightNameI  = string.format(".wheelWeight(%d)", i);
		local mass              = Vehicle.getConfigurationValue(self.xmlFile, key, wheelWeightNameI, "#mass", getXMLFloat, nil)
		if mass == nil then
      break
    end
		local wheelWeight       = {}
		wheelWeight.mass        = mass
    wheelWeight.wheelIndex  = Vehicle.getConfigurationValue(self.xmlFile, key, wheelWeightNameI, "#wheelIndex", getXMLInt,i)+1
		local wheel             = self.wheels[wheelWeight.wheelIndex]
		if wheel ~= nil then
			wheelWeight.wheelMass = wheel.mass
			wheel.mass            = wheel.mass + wheelWeight.mass
		end
		table.insert(self.wheelWeights,wheelWeight)
    i = i+1;
  end
end

--********************************
-- delete
--********************************
function wheelWeightConfig:delete()
end

--********************************
-- mouseEvent
--********************************
function wheelWeightConfig:mouseEvent(posX, posY, isDown, isUp, button)
end

--********************************
-- keyEvent
--********************************
function wheelWeightConfig:keyEvent(unicode, sym, modifier, isDown)
end

--********************************
-- update
--********************************
function wheelWeightConfig:update(dt)
end

--********************************
-- updateTick
--********************************
function wheelWeightConfig:updateTick(dt)
end

--********************************
-- draw
--********************************
function wheelWeightConfig:draw()
end  

